@@ -7,12 +7,12 @@
 #' @param ... extra arguments
 #' @param unit 
 #' the unit to be used in printing; defaults to \code{x}'s unit
-#' @param unit.prefix 
+#' @param prefix 
 #' the unit prefix to be used in printing; defaults to
-#' \code{x}'s unit.prefix
-#' @param unit.names 
+#' \code{x}'s prefix
+#' @param names 
 #' the unit names (short or long) to be used in printing;
-#' defaults to \code{x}'s unit.names
+#' defaults to \code{x}'s names
 #' @param digits 
 #' the number of decimal digits to print; default is 3
 #' 
@@ -35,14 +35,14 @@ NULL
 #' @rdname print-memuse
 #' @export
 setMethod("print", signature(x="memuse"),
-  function(x, ..., unit=x@unit, unit.prefix=x@unit.prefix, unit.names=x@unit.names, digits=3)
+  function(x, ..., unit=mu.unit(x), prefix=mu.prefix(x), names=mu.names(x), digits=3)
   {
-    if (unit.names != x@unit.names)
+    if (names != x@unit.names)
       x <- swap.names(x=x)
-    if (unit.prefix != x@unit.prefix)
+    if (prefix != x@unit.prefix)
       x <- swap.prefix(x=x)
     if (unit != x@unit)
-      x <- swap.unit(x=x, unit=unit, )
+      x <- swap.unit(x=x, unit=unit)
     
     unit <- tolower(x@unit)
     if (unit == "b" || unit == "bytes")
@@ -63,5 +63,5 @@ setMethod("print", signature(x="memuse"),
 #' @export
 setMethod("show", signature(object="memuse"),
   function(object) 
-    print(object, unit=object@unit, unit.prefix=object@unit.prefix, unit.names=object@unit.names, digits=3)
+    print(object, unit=mu.unit(object), prefix=mu.prefix(object), names=mu.names(object), digits=3)
 )
